@@ -1,5 +1,5 @@
 /*
- * $Id: lm-icmp.c,v 1.8 2004/07/15 23:22:02 jylefort Exp $
+ * $Id: lm-icmp.c,v 1.9 2004/10/08 22:56:58 jylefort Exp $
  *
  * Copyright (c) 1989, 1993 The Regents of the University of California
  * Copyright (c) 2004 Jean-Yves Lefort
@@ -184,7 +184,10 @@ lm_icmp_send_echo_request (const struct addrinfo *addrinfo,
   s = lm_sockets_get_by_domain(addrinfo->ai_family);
   g_return_val_if_fail(s != NULL, FALSE);
 
-  sent_len = sendto(s->s, buf, packet_len, 0, addrinfo->ai_addr, addrinfo->ai_addrlen);
+  do
+    sent_len = sendto(s->s, buf, packet_len, 0, addrinfo->ai_addr, addrinfo->ai_addrlen);
+  while (sent_len < 0 && errno == EINTR);
+
   if (sent_len != packet_len)
     {
       if (sent_len < 0)
@@ -310,7 +313,10 @@ lm_icmp_receive (const LMSocket *s, LMICMPReply *reply)
   g_return_val_if_fail(s != NULL, FALSE);
   g_return_val_if_fail(reply != NULL, FALSE);
 
-  nbytes = recvfrom(s->s, buf, sizeof(buf), 0, NULL, NULL);
+  do
+    nbytes = recvfrom(s->s, buf, sizeof(buf), 0, NULL, NULL);
+  while (nbytes < 0 && errno == EINTR);
+
   if (nbytes > 0)
     {
       GTimeVal tval_received;
