@@ -1,5 +1,5 @@
 /*
- * $Id: lm-preferences.c,v 1.10 2004/08/21 21:15:14 jylefort Exp $
+ * $Id: lm-preferences.c,v 1.11 2004/10/07 18:36:05 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -114,10 +114,12 @@ lm_preferences_display (void)
   gtk_widget_show(preferences.list);
 
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(preferences.list));
-  g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(lm_preferences_selection_changed_h), NULL);
+  g_signal_connect(selection, "changed", G_CALLBACK(lm_preferences_selection_changed_h), NULL);
 
-  g_signal_connect(G_OBJECT(preferences.list), "notify::can-go-up", G_CALLBACK(lm_preferences_update_sensitivity), NULL);
-  g_signal_connect(G_OBJECT(preferences.list), "notify::can-go-down", G_CALLBACK(lm_preferences_update_sensitivity), NULL);
+  g_object_connect(preferences.list,
+		   "signal::notify::can-go-up", lm_preferences_update_sensitivity, NULL,
+		   "signal::notify::can-go-down", lm_preferences_update_sensitivity, NULL,
+		   NULL);
 
   size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
   gtk_size_group_add_widget(size_group, preferences.delay_label);
