@@ -1,5 +1,5 @@
 /*
- * $Id: lm-util.c,v 1.11 2004/08/21 21:15:14 jylefort Exp $
+ * $Id: lm-util.c,v 1.15 2004/10/07 18:29:14 jylefort Exp $
  *
  * Copyright (c) 1989, 1993 The Regents of the University of California
  * Copyright (c) 2004 Jean-Yves Lefort
@@ -49,47 +49,30 @@
 #include <errno.h>
 #include <gnome.h>
 #include <glade/glade.h>
+#include <eel/eel.h>
+#include <eel/eel-alert-dialog.h>
 #include "lm-util.h"
-#include "lm-dialog.h"
 
 /*** functions ***************************************************************/
 
 static GtkWidget *lm_menu_item_new (const char *stock_id, const char *mnemonic);
+static void lm_error_dialog_real (GtkWindow *parent,
+				  gboolean blocking,
+				  const char *primary,
+				  const char *secondary);
 
 /*** implementation **********************************************************/
 
 /**
- * lm_pointers_free:
- * @list: the list of heap pointers to free
+ * lm_g_object_slist_free:
+ * @list: a #GSList of #GObject instances
  *
- * Frees @list, which must be a list containing heap pointers.
+ * Equivalent of eel_g_object_list_free() for a singly-linked list.
  **/
 void
-lm_pointers_free (GSList *list)
+lm_g_object_slist_free (GSList *list)
 {
-  GSList *l;
-
-  LM_LIST_FOREACH(l, list)
-    g_free(l->data);
-
-  g_slist_free(list);
-}
-
-/**
- * lm_objects_free:
- * @list: the list of GObject instances to free
- *
- * Frees @list, which must be a list containing GObject instances.
- **/
-void
-lm_objects_free (GSList *list)
-{
-  GSList *l;
-
-  LM_LIST_FOREACH(l, list)
-    g_object_unref(l->data);
-
-  g_slist_free(list);
+  eel_g_slist_free_deep_custom(list, (GFunc) g_object_unref, NULL);
 }
 
 void
@@ -161,11 +144,8 @@ lm_thread_create (GThreadFunc func, gpointer data)
   
   if (! g_thread_create(func, data, FALSE, &err))
     {
-      lm_error_dialog(_("A fatal error has occurred in Link Monitor"),
-		      _("Unable to create a thread: %s."),
-		      err->message);
+      lm_fatal_error_dialog(NULL, _("Unable to create a thread: %s."), err->message);
       g_error_free(err);
-      exit(1);
     }
 }
 
@@ -184,28 +164,6 @@ lm_time (void)
   return t;
 }
 
-char *
-lm_strdup_ftime (const char *format, const struct tm *timeptr)
-{
-#define STRDUP_FTIME_BUFSIZE_INCREMENT	1024
-#define STRDUP_FTIME_MAX_BUFSIZE	0xFFFF
-  char *buf;
-  size_t bufsize = STRDUP_FTIME_BUFSIZE_INCREMENT;
-
-  g_return_val_if_fail(format != NULL, NULL);
-  g_return_val_if_fail(timeptr != NULL, NULL);
-
-  buf = g_malloc(bufsize);
-  while (strftime(buf, bufsize, format, timeptr) == 0)
-    {
-      bufsize += STRDUP_FTIME_BUFSIZE_INCREMENT;
-      g_assert(bufsize <= STRDUP_FTIME_MAX_BUFSIZE);
-      buf = g_realloc(buf, bufsize);
-    }
-
-  return buf;
-}
-
 /*
  * Subtract 2 timeval structs: out = out - in. Out is assumed to be >=
  * in (based on tvsub() from FreeBSD's ping.c).
@@ -231,7 +189,7 @@ lm_display_help (const char *link_id)
 
   if (! gnome_help_display("link-monitor-applet.xml", link_id, &err))
     {
-      lm_error_dialog(_("Unable to display help"), "%s", err->message);
+      lm_error_dialog(NULL, _("Unable to display help"), "%s", err->message);
       g_error_free(err);
     }
 }
@@ -258,7 +216,7 @@ lm_display_help (const char *link_id)
  * will be created.
  *
  * Return value: the new menu item
- */
+ **/
 GtkWidget *
 lm_menu_shell_append (GtkMenuShell *shell,
 		      const char *stock_id,
@@ -299,3 +257,72 @@ lm_menu_item_new (const char *stock_id, const char *mnemonic)
   
   return item;
 }
+
+static void
+lm_error_dialog_real (GtkWindow *parent,
+		      gboolean blocking,
+		      const char *primary,
+		      const char *secondary)
+{
+  GtkWidget *dialog;
+
+  dialog = eel_alert_dialog_new(parent,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_OK,
+				primary,
+				secondary,
+				NULL);
+
+  if (blocking)
+    {
+      gtk_dialog_run(GTK_DIALOG(dialog));
+      gtk_widget_destroy(dialog);
+    }
+  else
+    {
+      g_signal_connect(dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
+      gtk_widget_show(dialog);
+    }
+}
+
+void
+lm_error_dialog (GtkWindow *parent,
+		 const char *primary,
+		 const char *format,
+		 ...)
+{
+  char *secondary;
+
+  if (format)
+    {
+      va_list args;
+      
+      va_start(args, format);
+      secondary = g_strdup_vprintf(format, args);
+      va_end(args);
+    }
+  else
+    secondary = NULL;
+
+  lm_error_dialog_real(parent, FALSE, primary, secondary);
+  g_free(secondary);
+}
+
+void
+lm_fatal_error_dialog (GtkWindow *parent, const char *format, ...)
+{
+  va_list args;
+  char *secondary;
+
+  g_return_if_fail(format != NULL);
+
+  va_start(args, format);
+  secondary = g_strdup_vprintf(format, args);
+  va_end(args);
+
+  lm_error_dialog_real(parent, TRUE, _("A fatal error has occurred in Link Monitor"), secondary);
+  g_free(secondary);
+
+  exit(1);
+}
