@@ -1,5 +1,5 @@
 /*
- * $Id: lm-util.h,v 1.5 2004/08/21 21:15:14 jylefort Exp $
+ * $Id: lm-util.h,v 1.8 2004/10/07 18:29:14 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -43,17 +43,22 @@ for ((var) = (head);				\
      (var);					\
      (var) = (var)->next)
 
-void lm_pointers_free (GSList *list);
-void lm_objects_free (GSList *list);
+void lm_g_object_slist_free (GSList *list);
 void lm_create_interface (const char *name, ...);
 GdkPixbuf *lm_pixbuf_new (const char *filename);
 void lm_thread_create (GThreadFunc func, gpointer data);
 time_t lm_time (void);
-char *lm_strdup_ftime (const char *format, const struct tm *timeptr);
 void lm_tvsub (GTimeVal *out, const GTimeVal *in);
 void lm_display_help (const char *link_id);
 GtkWidget *lm_menu_shell_append (GtkMenuShell *shell,
 				 const char *stock_id,
 				 const char *mnemonic);
+void lm_error_dialog (GtkWindow *parent,
+		      const char *primary,
+		      const char *format,
+		      ...) G_GNUC_PRINTF(3, 4);
+void lm_fatal_error_dialog (GtkWindow *parent,
+			    const char *format,
+			    ...) G_GNUC_PRINTF(2, 3);
 
 #endif /* _LM_UTIL_H */
